# Disambiguation Test Page

[Single Parent Index Search (should expand to sub1/sub2/index.md)](sub2/index.md)
[Dual Parent Index Search (should expand to sub1/sub2/index.md](sub1/sub2/index.md)

[Single Parent Index Search](sub2/index.md)
[Dual Parent Index Search](sub1/sub2/index.md)


[Single Parent Index Search](sub2/index)
[Dual Parent Index Search](sub1/sub2/index)
[Test](sub3/about)

[Partial](sub4/index)

[[my-project/index|Test Title!!]]

[[sub4/index|Sub4 Index]]
